<?php
/*
  Plugin Name: Buddypress Activity Anywhere
  Plugin URI: http://geomywp.com
  Description: Let your Buddypress members quick post something to activity from anywhere on the screen from any page.
  Author: Eyal Fitoussi
  Version: 1.1
  Author URI: http://geomywp.com
  Text Domain: BPQA
  Domain Path: /languages/
*/
/*
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License (Version 2 - GPLv2) as published by
 the Free Software Foundation.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
 * BP_Activity_Anywhere class
 * @since 1.0
 * 
 */
class BP_Activity_Anywhere {

    /**
     * __constructor
     * 
     * @since 1.0
     * @return type
     */
    public function __construct() {

        $this->settings = get_option( 'bpqa_options' );

        define( 'BPQA_URL', untrailingslashit( plugins_url( basename( plugin_dir_path( __FILE__ ) ), basename( __FILE__ ) ) ) );
        define( 'BPQA_PATH', untrailingslashit( plugin_dir_path( __FILE__ ) ) );
		define( 'BPQA_VERSION', '1.1' );
		
        //load admin pages
        if ( is_admin() && !defined( 'DOING_AJAX' ) ) {
            include_once BPQA_PATH . '/includes/bpqa-admin.php';
            return;
        }

        //if user logged out no need to load the plugin
        if ( !is_user_logged_in() )
            return;

        //submit activity
        if ( !is_admin() ) {
            self::submit_activity();
        }

        add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
        add_action( 'admin_bar_menu', array( $this, 'adminbar_button' ), 100 );
        add_action( 'wp_footer', array( $this, 'activity_form' ) );

    }

    //register style
    function enqueue_scripts() {
        wp_enqueue_style( 'bpqa-style', BPQA_URL . '/form-templates/default/css/style.css' );
        wp_register_script( 'bpqa-js', BPQA_URL . '/assets/js/js.js', array( 'jquery' ), BPQA_VERSION, true );

    }

    /**
     * Add button to adminbar
     * @global type $wp_admin_bar
     * @param type $admin_bar
     * @return type
     */
    public function adminbar_button( $admin_bar ) {

        // add link to toobar if needed    
        if ( !isset( $this->settings['toolbar_button']['use'] ) || $this->settings['toolbar_button']['use'] != 1 )
            return;

        global $wp_admin_bar;

        $admin_bar->add_menu( array(
            'id'    => 'bpqa-post-update',
            'title' => $this->settings['toolbar_button']['title'],
            'href'  => '#',
            'meta'  => array(
                'title' => $this->settings['toolbar_button']['title'],
                'class' => 'bpqa-form-trigger'
            ),
        ) );

    }

    /**
     * Activity form - we silently load it to the footer
     * 
     */
    function activity_form() {
		
        include_once BPQA_PATH . '/form-templates/default/form.php';
        wp_enqueue_script( 'bpqa-js' );
        		
    }

    /**
     * Submit new activity
     * @global type $bp
     */
    public function submit_activity() {

        // create the new activity and save to activity table
    	if ( $_SERVER['REQUEST_METHOD'] == 'POST' && isset( $_POST['bpqa_update_activity'] ) && wp_verify_nonce( $_POST['bpqa_update_activity'], 'bpqa_submit_form' ) && (!empty( $_POST['bpqa_textarea'] ) ) ) {

    		global $bp;

    		$activity_args = array(
    				'action'			=> apply_filters( 'bpqa_profile_new_activity_message', sprintf( __( '%1$s Posted an update', 'BPQA' ), bp_core_get_userlink( $bp->loggedin_user->id ), '' ) ),
    				'content'           => $_POST['bpqa_textarea'],
    				'component'         => 'profile',
    				'type'              => 'activity_update',
    				'primary_link'      => '',
    				'user_id'           => $bp->loggedin_user->id,
    				'item_id'           => 0,
    				'secondary_item_id' => false,
    				'recorded_time'     => gmdate( "Y-m-d H:i:s" ),
    				'hide_sitewide'     => false
    		);
    		$activity_id   = bp_activity_add( $activity_args );
       
    	}

    }

}

function bpaa_init() {
    new BP_Activity_Anywhere();

}
// load plugin
add_action( 'bp_init', 'bpaa_init' );
?>