<?php
/*
 * BPQA admin settings page
 */
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) )
    exit;

/**
 * BPQA admin function - add menu items to admin dashboard
 */
function bpqa_admin_menu() {

    //add settings page menu item
    add_submenu_page( 'options-general.php', 'quick-activity', __( 'Quick Activity', 'BPQA' ), 'manage_options', 'bpqa_settings', 'bpqa_settings_page' );

}
add_action( 'admin_menu', 'bpqa_admin_menu' );

/*
 * Set the default options page if not exist
 */

function bpqa_options_init() {
    global $bpqa_options;
    //get the options 

    $bpqa_options = get_option( 'bpqa_options' );
    //check if not exists
    if ( false === $bpqa_options ) {
        //default options
        $options = array(
            'toolbar_button'  => array( 'use' => 0, 'title' => 'Say Something' ),
            'floating_button' => array( 'use' => 1, 'top' => '100', 'location' => 'left', 'icon' => 'bpqa-button-light-blue.png' ),
        );
        //update default options
        update_option( 'bpqa_options', $options );
    }

}
add_action( 'admin_init', 'bpqa_options_init' );

/*
 * Main settings page
 */

function bpqa_settings_page() {
    ?>
    <div class="wrap">
        <h2><?php _e( 'Buddypress Quick Activity Settings Page', 'BPQA' ); ?></h2>
        <form action="options.php" method="post">
            <?php
            settings_fields( 'bpqa_options' );
            do_settings_sections( 'bpqa' );
            ?>
            <div class="clear"></div>
            <input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Settings', 'BPQA' ); ?>" />
        </form>
        <br >
        <br >
        <div style="font-size: 14px;font-style: italic;">
            <h2 style="margin-bottom:10px"><?php _e( 'Shortcode usage - <a href="http://codecanyon.net/item/buddypress-quick-activity/7112239" target="_blank">See the premium version for more features</a>', 'BPQA' ); ?></h2>
            <?php _e( 'Another way to display the "Quick Activity" button is using a shortcode. You can place the shortcode <code>[bpqa_button]</code> in the content area of any post or page.
            You can also use <code><&#63;php echo do_shortcode(\'[bpqa_button]\'); &#63;></code> anywhere in your template files.<br />
            The shorcode accepts the attributes below:','BPQA');?>
            <ol>
                <li><strong>Type</strong><?php _e( ' - Excepts the values button, link or image. The "type" attribute controls the way the "Quick Activity" button will be displayed.','BPQA'); ?>
                    <ol>
                        <li><?php _e( 'The value "button" will create an HTML input type button.','BPQA'); ?></li>
                        <li><?php _e( 'The value "Link" will create an hyperlink','BPQA'); ?></li>
                        <li><?php _e( 'The value "Image" will display the "Quick Activity" button as an image','BPQA'); ?></li>
                    </ol>
                </li>
                <li><strong>Img</strong><?php _e( ' - the attribute img will only work when choosing "image" as a value for the attribute "type". Using the attribute "img" you can choose the image that will be displayed as the "Quick Activity" button.
                    In order to use the "img" attribute its value needs to be the name of the image that you want to use. The image must be saved in the plugin\'s directory under buttons direcory. 
                    <code>wp-content/plugins/buddypress-quick-activity/buttons</code>','BPQA'); ?>
                </li>
                <li><strong>Title</strong><?php _e( ' - The "title" attribute will work when the "type" attributes gets either "button" or "link" values. Using the "title" attribute you can define the title of the  "Quick activity" button or link.','BPQA'); ?></li>
                <li><strong>class</strong><?php _e( ' - give the "Quick Activity" button a custom CLASS tag','BPQA'); ?></li>
                <li><strong>id</strong><?php _e( ' - give the "Quick Activity" button a custom ID tag','BPQA'); ?></li>
            </ol>

        </div>

        <h2 style="margin-bottom:10px"><?php _e( 'Shortcodes examples:','BPQA'); ?></h2>
        <ol>
            <li><?php _e( 'Create "Quick Activity" button with the title "Say Something" - <code>[bpqa_button type="button" title="say something"]</code>','BPQA'); ?></li>
            <li><?php _e( 'Create "Quick Activity" link with the title "Post Update" - <code>[bpqa_button type="link" title="Post Update"]</code>','BPQA'); ?></li>
            <li><?php _e( 'Create "Quick Activity" image button - <code>[bpqa_button type="image" img="bpqa-button-green.png"]</code>','BPQA'); ?></li>
        </ol>
        <div style="padding:10px 0px;margin-top:20px;border-top:1px solid #e5e5e5;color:#777;"><?php _e( 'BuddyPress Quick Activity developed by <a style="text-decoration:none;" href="http://geomywp.com" target="_blank">Eyal Fitoussi</a>', 'BPQA' ); ?></div>
    </div>
    <?php

}
/*
 * register fields
 */

function bpqa_admin_register_settings() {
    global $blog_id;

    register_setting( 'bpqa_options', 'bpqa_options', 'bpqa_admin_options_validate' );

    // toolbar button sections and field
    add_settings_section( 'bpqa_toolbar_button_options', __( 'Quick Activity Admin-bar Button', 'BPQA' ), 'bpqa_toolbar_button_section_text', 'bpqa' );
    add_settings_field( 'bpqa_admin_toolbar_use', __( 'Admin-bar button', 'BPQA' ), 'bpqa_admin_toolbar_use', 'bpqa', 'bpqa_toolbar_button_options' );
    add_settings_field( 'bpqa_admin_toolbar_title', __( 'Title', 'BPQA' ), 'bpqa_admin_toolbar_title', 'bpqa', 'bpqa_toolbar_button_options' );

    //floating button sections and fields
    add_settings_section( 'bpqa_floating_button_options', __( 'Quick Activity Floating Button - <a href="http://codecanyon.net/item/buddypress-quick-activity/7112239" target="_blank">See the premium version for more features</a>', 'BPQA' ), 'bpqa_floating_button_section_text', 'bpqa' );
    add_settings_field( 'bpqa_admin_floating_use', __( 'Floating button', 'BPQA' ), 'bpqa_admin_floating_use', 'bpqa', 'bpqa_floating_button_options' );
    add_settings_field( 'bpqa_admin_floating_top', __( 'Top', 'BPQA' ), 'bpqa_admin_floating_top', 'bpqa', 'bpqa_floating_button_options' );
    add_settings_field( 'bpqa_admin_floating_locaiton', __( 'Location', 'BPQA' ), 'bpqa_admin_floating_location', 'bpqa', 'bpqa_floating_button_options' );
    add_settings_field( 'bpqa_admin_floating_icon', __( 'Icon', 'BPQA' ), 'bpqa_admin_floating_icon', 'bpqa', 'bpqa_floating_button_options' );

}
add_action( 'admin_init', 'bpqa_admin_register_settings' );

function bpqa_toolbar_button_section_text() {
    ?>
    <p><?php _e( 'Add "Quick Activity" button to the admin-bar.', 'BPQA' ); ?></p>
    <?php

}

function bpqa_admin_toolbar_use() {
    $bpqa_options = get_option( 'bpqa_options' );
    ?>
    <input type="checkbox" name="bpqa_options[toolbar_button][use]" <?php if ( isset( $bpqa_options['toolbar_button']['use'] ) && $bpqa_options['toolbar_button']['use'] == 1 ) echo 'checked="checked"'; ?> value="1" />
    <span class="description"><?php _e( 'Quick Activity button will be added to the toolbar', 'BPQA' ); ?></span>
    <?php

}

function bpqa_admin_toolbar_title() {
    $bpqa_options = get_option( 'bpqa_options' );
    ?>
    <input type="text" name="bpqa_options[toolbar_button][title]" value="<?php echo $bpqa_options['toolbar_button']['title']; ?>" />
    <span class="description"><?php _e( 'Give the button a title', 'BPQA' ); ?></span>
    <?php

}

function bpqa_floating_button_section_text() {
    ?>
    <p><?php _e( 'Display a floating "Quick Activity" button in the left or right side of the screen', 'BPQA' ); ?></p>
    <?php

}

function bpqa_admin_floating_use() {
    $bpqa_options = get_option( 'bpqa_options' );
    ?>
    <input disabled="disabled" type="checkbox" <?php if ( isset( $bpqa_options['floating_button']['use'] ) && $bpqa_options['floating_button']['use'] == 1 ) echo 'checked="checked"'; ?> name="bpqa_options[floating_button][use]" value="1" />
    <span class="description"><?php _e( 'Display a floating button', 'BPQA' ); ?></span>
    <?php

}

function bpqa_admin_floating_top() {
    $bpqa_options = get_option( 'bpqa_options' );
    ?>
    <input disabled="disabled" type="text" name="bpqa_options[floating_button][top]" size="5" value="<?php echo $bpqa_options['floating_button']['top']; ?>" />px
    <span class="description"><?php _e( 'Define the "Top" attribute for the button in pixels', 'BPQA' ); ?></span>
    <?php

}

function bpqa_admin_floating_location() {
    $bpqa_options = get_option( 'bpqa_options' );
    ?>
    <select disabled="disabled" name="bpqa_options[floating_button][location]" >
        <option <?php if ( $bpqa_options['floating_button']['location'] == 'left' ) echo 'selected="selected"'; ?> value="left"><?php _e( 'Left', 'BPQA' ); ?></option>
        <option <?php if ( $bpqa_options['floating_button']['location'] == 'right' ) echo 'selected="selected"'; ?> value="right"><?php _e( 'Right', 'BPQA' ); ?></option>
    </select>
    <span class="description"><?php _e( 'Which side of the scrren you wish to display the button', 'BPQA' ); ?></span>
    <?php

}

function bpqa_admin_floating_icon() {
    $bpqa_options = get_option( 'bpqa_options' );
    $map_icons    = glob( BPQA_PATH . '/buttons/*.*' );
    $display_icon = BPQA_URL . '/buttons/';
    $cic          = 1;
    foreach ( $map_icons as $map_icon ) :
        echo '<span><input type="radio" name="bpqa_options[floating_button][icon]" disabled="disabled" value="' . basename( $map_icon ) . '"';
        echo ( ( isset( $bpqa_options['floating_button']['icon'] ) && $bpqa_options['floating_button']['icon'] == basename( $map_icon ) ) || $cic == 1 ) ? ' checked="checked" ' : '';
        echo ' />
		<img src="' . $display_icon . basename( $map_icon ) . '" height="40px" width="35px"/></span>';
        $cic++;
    endforeach;

}
/*
 * Validate the updated values and return them to be saved 
 */

function bpqa_admin_options_validate( $input ) {

    $bpqa_options = get_option( 'bpqa_options' );

    $valid_input = $bpqa_options;

    $valid_input['toolbar_button']['use']       = ( isset( $input['toolbar_button']['use'] ) && $input['toolbar_button']['use'] == 1 ) ? 1 : 0;
    $valid_input['toolbar_button']['title']     = (!empty( $input['toolbar_button']['title'] ) ) ? $input['toolbar_button']['title'] : 'Say Something';
    $valid_input['floating_button']['use']      = ( isset( $input['floating_button']['use'] ) && $input['floating_button']['use'] == 1 ) ? 1 : 0;
    $valid_input['floating_button']['location'] = ( $input['floating_button']['location'] == 'right' ) ? 'right' : 'left';
    $valid_input['floating_button']['top']      = (!empty( $input['floating_button']['top'] ) ) ? $input['floating_button']['top'] : '100';
    $valid_input['floating_button']['icon']     = $input['floating_button']['icon'];

    return $valid_input;

}
